@@ -18,9 +18,7 @@
  *          Federico Mena Quintero <federico@gnome.org>
  */
 
-
-#ifndef __NAUTILUS_FREEDESKTOP_DBUS_H__
-#define __NAUTILUS_FREEDESKTOP_DBUS_H__
+#pragma once
 
 #include <glib-object.h>
 
@@ -48,4 +46,4 @@ NautilusFreedesktopDBus * nautilus_freedesktop_dbus_new (void);
 
 void nautilus_freedesktop_dbus_set_open_locations (NautilusFreedesktopDBus *fdb, const gchar **locations);
 
-#endif /* __NAUTILUS_FREEDESKTOP_DBUS_H__ */
+void nautilus_freedesktop_dbus_set_open_windows_with_locations (NautilusFreedesktopDBus *fdb, GVariant *locations);
