@@ -21,8 +21,7 @@
    Authors: Ramiro Estrugo <ramiro@eazel.com>
 */
 
-#ifndef NAUTILUS_GLOBAL_PREFERENCES_H
-#define NAUTILUS_GLOBAL_PREFERENCES_H
+#pragma once
 
 #include "nautilus-global-preferences.h"
 #include <gio/gio.h>
@@ -135,18 +134,12 @@ typedef enum
 	NAUTILUS_SIMPLE_SEARCH_BAR
 } NautilusSearchBarMode;
 
-/* bulk rename utility */
-#define NAUTILUS_PREFERENCES_BULK_RENAME_TOOL              "bulk-rename-tool"
-
 /* Lockdown */
 #define NAUTILUS_PREFERENCES_LOCKDOWN_COMMAND_LINE         "disable-command-line"
 
 /* Recent files */
 #define NAUTILUS_PREFERENCES_RECENT_FILES_ENABLED          "remember-recent-files"
 
-/* Move to trash shorcut changed dialog */
-#define NAUTILUS_PREFERENCES_SHOW_MOVE_TO_TRASH_SHORTCUT_CHANGED_DIALOG "show-move-to-trash-shortcut-changed-dialog"
-
 /* Default view when searching */
 #define NAUTILUS_PREFERENCES_SEARCH_VIEW "search-view"
 
@@ -173,5 +166,3 @@ extern GSettings *gnome_background_preferences;
 extern GSettings *gnome_interface_preferences;
 
 G_END_DECLS
-
-#endif /* NAUTILUS_GLOBAL_PREFERENCES_H */
